@@ -41,12 +41,16 @@ SHORT_URL_CHARS = (string.ascii_lowercase + string.ascii_uppercase +
     '0', '')
 SUB_RESPONSE_TIMEOUT = 10
 HTTP_REQUEST_TIMEOUT = 10
-HTTP_COM_REQUEST_TIMEOUT = 60
+SOCKET_PING_INTERVAL = 3
+SOCKET_TIMEOUT = 10
 SERVER_REQUEST_QUEUE_SIZE = 512
 USER_PAGE_COUNT = 10
 NODE_SERVER_VER = 1
+CLIENT_CONF_VER = 1
 STATIC_CACHE_TIME = 43200
+LOCALHOST_IP_TTL = 30
 IP_REGEX = r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}'
+SAFE_PUB_SUBNETS = {'50.203.224.0/24'}
 
 INFO = 'info'
 WARNING = 'warning'
@@ -94,7 +98,6 @@ LOG_UPDATED = 'log_updated'
 SERVERS_UPDATED = 'servers_updated'
 SERVER_ORGS_UPDATED = 'server_organizations_updated'
 SERVER_OUTPUT_UPDATED = 'server_output_updated'
-SERVER_BANDWIDTH_UPDATED = 'server_bandwidth_updated'
 
 CERT_CONF = """[ default ]
 ca = %s
@@ -251,10 +254,10 @@ client-connect %s
 client-disconnect %s
 dh %s
 server %s
-ifconfig-pool-persist %s
+ifconfig-pool-persist %s 604800
 %s
 max-clients 1024
-keepalive 5 20
+keepalive 10 30
 persist-tun
 status %s 1
 status-version 2
@@ -270,10 +273,10 @@ tls-verify %s
 client-connect %s
 client-disconnect %s
 server %s
-ifconfig-pool-persist %s
+ifconfig-pool-persist %s 604800
 %s
 max-clients 1024
-keepalive 5 20
+keepalive 10 30
 persist-tun
 status %s 1
 status-version 2
@@ -282,7 +285,8 @@ verb %s
 mute %s
 """
 
-OVPN_CLIENT_CONF = """client
+OVPN_CLIENT_CONF = """# %s
+client
 dev tun
 proto %s
 remote %s %s
@@ -295,7 +299,8 @@ verb 2
 mute 3
 """
 
-OVPN_INLINE_CLIENT_CONF = """client
+OVPN_INLINE_CLIENT_CONF = """# %s
+client
 dev tun
 proto %s
 remote %s %s
