@@ -251,6 +251,7 @@ class Server(Config):
         self.commit()
         Event(type=SERVERS_UPDATED)
         Event(type=SERVER_ORGS_UPDATED, resource_id=self.id)
+        Event(type=USERS_UPDATED, resource_id=org_id)
         return org
 
     def _remove_primary_user(self):
@@ -290,6 +291,7 @@ class Server(Config):
         self.commit()
         Event(type=SERVERS_UPDATED)
         Event(type=SERVER_ORGS_UPDATED, resource_id=self.id)
+        Event(type=USERS_UPDATED, resource_id=org_id)
 
     def iter_orgs(self):
         orgs_dict = {}
@@ -490,7 +492,7 @@ class Server(Config):
         rules = []
 
         try:
-            routes_output = utils.check_output(['route', '-n'],
+            routes_output = subprocess.check_output(['route', '-n'],
                 stderr=subprocess.PIPE)
         except subprocess.CalledProcessError:
             logger.exception('Failed to get IP routes. %r' % {
@@ -654,6 +656,9 @@ class Server(Config):
             self._interrupt = True
             status_thread.join()
 
+            cache_db.remove(self.get_cache_key('clients'))
+            cache_db.dict_remove(self.get_cache_key(), 'clients')
+
             self.status = False
             self.publish('stopped')
             if process.returncode != 0:
@@ -761,6 +766,7 @@ class Server(Config):
     def restart(self, silent=False):
         if not self.status:
             self.start()
+            return
         logger.debug('Restarting server. %r' % {
             'server_id': self.id,
         })
@@ -1014,8 +1020,6 @@ class Server(Config):
                         persist_db.dict_remove(self.get_cache_key(
                             'bandwidth-%s' % period), timestamp_p)
 
-            Event(type=SERVER_BANDWIDTH_UPDATED, resource_id=self.id)
-
     def _read_clients(self):
         clients = {}
         if os.path.isfile(self.ovpn_status_path):
