@@ -24,29 +24,35 @@ AUTH_HANDLERS = [
     ('PUT', '/auth'),
     ('GET', '/export'),
     ('GET', '/event'),
-    ('GET', '/key/0/0.tar'),
-    ('GET', '/key/0/0'),
+    ('GET', '/key/a1/a1.tar'),
+    ('GET', '/key/a1/a1'),
     ('GET', '/log'),
     ('GET', '/organization'),
+    ('GET', '/organization/a1'),
     ('POST', '/organization'),
-    ('PUT', '/organization/0'),
-    ('DELETE', '/organization/0'),
+    ('PUT', '/organization/a1'),
+    ('DELETE', '/organization/a1'),
     ('GET', '/server'),
+    ('GET', '/server/a1'),
     ('POST', '/server'),
-    ('PUT', '/server/0'),
-    ('DELETE', '/server/0'),
-    ('GET', '/server/0/organization'),
-    ('PUT', '/server/0/organization/0'),
-    ('DELETE', '/server/0/organization/0'),
-    ('PUT', '/server/0/0'),
-    ('GET', '/server/0/output'),
-    ('DELETE', '/server/0/output'),
+    ('PUT', '/server/a1'),
+    ('DELETE', '/server/a1'),
+    ('GET', '/server/a1/organization'),
+    ('PUT', '/server/a1/organization/a1'),
+    ('DELETE', '/server/a1/organization/a1'),
+    ('PUT', '/server/a1/a1'),
+    ('GET', '/server/a1/output'),
+    ('DELETE', '/server/a1/output'),
+    ('GET', '/server/a1/bandwidth'),
+    ('GET', '/server/a1/bandwidth/1m'),
     ('GET', '/status'),
-    ('GET', '/user/0'),
-    ('POST', '/user/0'),
-    ('PUT', '/user/0/0'),
-    ('DELETE', '/user/0/0'),
-    ('PUT', '/user/0/0/otp_secret'),
+    ('GET', '/user/a1'),
+    ('GET', '/user/a1/1'),
+    ('GET', '/user/a1/a1'),
+    ('POST', '/user/a1'),
+    ('PUT', '/user/a1/a1'),
+    ('DELETE', '/user/a1/a1'),
+    ('PUT', '/user/a1/a1/otp_secret'),
 ]
 RUN_ONLY = []
 
@@ -54,7 +60,7 @@ def _log_request(method, endpoint, start_time):
     if endpoint.startswith('/event'):
         return
     response_time = int((time.time() - start_time) * 1000)
-    if endpoint.startswith('/auth'):
+    if endpoint.startswith('/auth') or endpoint.startswith('/k/'):
         if response_time > 900:
             color = '\033[92m'
         elif response_time > 700:
@@ -433,7 +439,7 @@ class Key(SessionTestCase):
         self.assertRegexpMatches(content_disposition, exp)
 
     @unittest.skipUnless(ENABLE_STANDARD_TESTS, 'Skipping test')
-    def test_user_key_link_get(self):
+    def test_user_key_link_get_delete(self):
         response = self.session.put('/server/%s/organization/%s' % (
             self.server_id, self.org_id))
         self.assertEqual(response.status_code, 200)
@@ -474,7 +480,7 @@ class Key(SessionTestCase):
 
 
         start_index = response.text.find('<h4 class="key-title">') + 22
-        end_index = response.text.find('</h2>', start_index)
+        end_index = response.text.find('</h4>', start_index)
         self.assertNotEqual(start_index, -1)
         self.assertNotEqual(end_index, -1)
         key_title = response.text[start_index:end_index]
@@ -522,6 +528,22 @@ class Key(SessionTestCase):
         self.assertRegexpMatches(otp_key, exp)
 
 
+        start_index = response.text.find("xmlhttp.open('DELETE', '") + 24
+        end_index = response.text.find("', false);", start_index)
+        self.assertNotEqual(start_index, -1)
+        self.assertNotEqual(end_index, -1)
+        delete_link = response.text[start_index:end_index]
+        self.assertEqual(data['view_url'], delete_link)
+
+
+        response = self.session.delete(data['view_url'])
+        self.assertEqual(response.status_code, 200)
+
+
+        response = self.session.get(data['view_url'])
+        self.assertEqual(response.status_code, 404)
+
+
         response = self.session.delete('/server/%s/organization/%s' % (
             self.server_id, self.org_id))
         self.assertEqual(response.status_code, 200)
@@ -544,6 +566,16 @@ class Log(SessionTestCase):
 
 class Org(SessionTestCase):
     @unittest.skipUnless(ENABLE_STANDARD_TESTS, 'Skipping test')
+    def test_org_get(self):
+        response = self.session.get('/organization/%s' % self.org_id)
+        self.assertEqual(response.status_code, 200)
+
+        data = response.json()
+        self.assertIn('id', data)
+        self.assertEqual(data['id'], self.org_id)
+        self.assertIn('name', data)
+        self.assertEqual(data['name'], TEST_ORG_NAME)
+
     def test_org_post_put_get_delete(self):
         response = self.session.post('/organization', json_data={
             'name': TEST_ORG_NAME + '2',
@@ -601,6 +633,17 @@ class Org(SessionTestCase):
 
 
 class Server(SessionTestCase):
+    @unittest.skipUnless(ENABLE_STANDARD_TESTS, 'Skipping test')
+    def test_server_get(self):
+        response = self.session.get('/server/%s' % self.server_id)
+        self.assertEqual(response.status_code, 200)
+
+        data = response.json()
+        self.assertIn('id', data)
+        self.assertEqual(data['id'], self.server_id)
+        self.assertIn('name', data)
+        self.assertEqual(data['name'], TEST_SERVER_NAME)
+
     @unittest.skipUnless(ENABLE_STANDARD_TESTS, 'Skipping test')
     def test_server_post_put_get_delete(self):
         response = self.session.post('/server', json_data={
@@ -832,6 +875,58 @@ class Server(SessionTestCase):
         self.assertIn('output', data)
         self.assertEqual(data['output'], '')
 
+    @unittest.skipUnless(ENABLE_STANDARD_TESTS, 'Skipping test')
+    def test_server_bandwidth_get(self):
+        lengths = {
+            '1m': 360,
+            '5m': 288,
+            '30m': 336,
+            '2h': 360,
+            '1d': 365,
+        }
+
+        response = self.session.get('/server/%s/bandwidth' % self.server_id)
+        self.assertEqual(response.status_code, 200)
+
+        data = response.json()
+        self.assertIn('1m', data)
+        self.assertIn('received', data['1m'])
+        self.assertEqual(len(data['1m']['received']), lengths['1m'])
+        self.assertIn('sent', data['1m'])
+        self.assertEqual(len(data['1m']['sent']), lengths['1m'])
+        self.assertIn('5m', data)
+        self.assertIn('received', data['5m'])
+        self.assertEqual(len(data['5m']['received']), lengths['5m'])
+        self.assertIn('sent', data['5m'])
+        self.assertEqual(len(data['5m']['sent']), lengths['5m'])
+        self.assertIn('30m', data)
+        self.assertIn('received', data['30m'])
+        self.assertEqual(len(data['30m']['received']), lengths['30m'])
+        self.assertIn('sent', data['30m'])
+        self.assertEqual(len(data['30m']['sent']), lengths['30m'])
+        self.assertIn('2h', data)
+        self.assertIn('received', data['2h'])
+        self.assertEqual(len(data['2h']['received']), lengths['2h'])
+        self.assertIn('sent', data['2h'])
+        self.assertEqual(len(data['2h']['sent']), lengths['2h'])
+        self.assertIn('1d', data)
+        self.assertIn('received', data['1d'])
+        self.assertEqual(len(data['1d']['received']), lengths['1d'])
+        self.assertIn('sent', data['1d'])
+        self.assertEqual(len(data['1d']['sent']), lengths['1d'])
+
+
+        for period in ('1m', '5m', '30m', '2h', '1d'):
+            response = self.session.get('/server/%s/bandwidth/%s' % (
+                self.server_id, period))
+            self.assertEqual(response.status_code, 200)
+
+            data = response.json()
+            self.assertIn('received', data)
+            self.assertEqual(len(data['received']), lengths[period])
+            self.assertIn('sent', data)
+            self.assertEqual(len(data['sent']), lengths[period])
+
     @unittest.skipUnless(ENABLE_STANDARD_TESTS, 'Skipping test')
     def test_server_put_post_errors(self):
         response = self.session.put('/server/%s/organization/%s' % (
@@ -1007,6 +1102,17 @@ class Status(SessionTestCase):
 
 class User(SessionTestCase):
     @unittest.skipUnless(ENABLE_STANDARD_TESTS, 'Skipping test')
+    def test_user_get(self):
+        response = self.session.get('/user/%s/%s' % (
+            self.org_id, self.user_id))
+        self.assertEqual(response.status_code, 200)
+
+        data = response.json()
+        self.assertIn('id', data)
+        self.assertEqual(data['id'], self.user_id)
+        self.assertIn('name', data)
+        self.assertEqual(data['name'], TEST_USER_NAME)
+
     def test_user_post_put_get_delete(self):
         response = self.session.post('/user/%s' % self.org_id, json_data={
             'name': TEST_USER_NAME + '2',
