@@ -6,10 +6,11 @@ define([
   'use strict';
   var PasswordModel = Backbone.Model.extend({
     defaults: {
+      'username': null,
       'password': null
     },
     url: function() {
-      return '/password';
+      return '/auth';
     },
     isNew: function() {
       return false;
