@@ -6,12 +6,13 @@ define([
   'views/alert',
   'views/serverOrgsList',
   'views/serverOutput',
+  'views/serverBandwidth',
   'views/modalServerSettings',
   'views/modalDeleteServer',
   'text!templates/serversListItem.html'
 ], function($, _, Backbone, StatusModel, AlertView, ServerOrgsListView,
-    ServerOutputView, ModalServerSettingsView, ModalDeleteServerView,
-    serversListItemTemplate) {
+    ServerOutputView, ServerBandwidthView, ModalServerSettingsView,
+    ModalDeleteServerView, serversListItemTemplate) {
   'use strict';
   var ServersListItemView = Backbone.View.extend({
     className: 'server',
@@ -20,7 +21,10 @@ define([
       'click .server-title a': 'onSettings',
       'click .server-del': 'onDelete',
       'click .server-restart, .server-start, .server-stop': 'onOperation',
+      'click .server-output-btn': 'onServerOutput',
+      'click .server-graph-btn': 'onServerGraph',
       'click .server-output-clear': 'onClearOutput',
+      'click .server-graph-period': 'onServerGraphPeriod',
       'click .toggle-hidden': 'onToggleHidden'
     },
     initialize: function() {
@@ -33,6 +37,10 @@ define([
         server: this.model.get('id')
       });
       this.addView(this.serverOutputView);
+      this.serverBandwidthView = new ServerBandwidthView({
+        server: this.model.get('id')
+      });
+      this.addView(this.serverBandwidthView);
       setTimeout(function() {
         this.uptimer = setInterval((this._updateTime).bind(this), 1000);
       }.bind(this), 1000);
@@ -40,6 +48,13 @@ define([
     deinitialize: function() {
       clearInterval(this.uptimer);
     },
+    formatDate: function(epochTime) {
+        var dateString = new Date(epochTime * 1000).toUTCString();
+        var dateArray = dateString.split(' ');
+        dateArray[0] = dateArray[0].replace(',', '');
+
+        return dateArray[2] + ', ' + dateArray[1] + ' ' + dateArray[3];
+    },
     render: function() {
       this.$el.html(this.template(this.model.toJSON()));
       this.update();
@@ -48,11 +63,13 @@ define([
       });
       this.$('.server-output-viewer').append(
         this.serverOutputView.render().el);
+      this.$('.server-graph-viewer').append(
+        this.serverBandwidthView.render().el);
       this.$el.append(this.serverOrgsListView.render().el);
 
       if (this.model.get('type') === 'node_server') {
         this.$('.server-label').hide();
-        this.$('.server-output-viewer').addClass('node-output');
+        this.$el.addClass('node-server');
         this.$('.server-public-address').removeClass('last');
       }
       else {
@@ -242,6 +259,48 @@ define([
         }.bind(this)
       });
     },
+    onServerGraphPeriod: function(evt) {
+      this.$('.server-graph-period').removeClass('btn-primary');
+      this.$('.server-graph-period').addClass('btn-default');
+      $(evt.target).removeClass('btn-default');
+      $(evt.target).addClass('btn-primary');
+
+      if ($(evt.target).hasClass('graph-1m')) {
+        this.serverBandwidthView.setPeriod('1m');
+      }
+      else if ($(evt.target).hasClass('graph-5m')) {
+        this.serverBandwidthView.setPeriod('5m');
+      }
+      else if ($(evt.target).hasClass('graph-30m')) {
+        this.serverBandwidthView.setPeriod('30m');
+      }
+      else if ($(evt.target).hasClass('graph-2h')) {
+        this.serverBandwidthView.setPeriod('2h');
+      }
+      else if ($(evt.target).hasClass('graph-1d')) {
+        this.serverBandwidthView.setPeriod('1d');
+      }
+    },
+    onServerOutput: function() {
+      this.$('.server-output-btn').removeClass('btn-default');
+      this.$('.server-output-btn').addClass('btn-primary');
+      this.$('.server-graph-btn').removeClass('btn-primary');
+      this.$('.server-graph-btn').addClass('btn-default');
+      this.$('.server-graph-period').hide();
+      this.$('.server-output-clear').show();
+      this.serverBandwidthView.setState(false);
+      this.serverOutputView.setState(true);
+    },
+    onServerGraph: function() {
+      this.$('.server-output-btn').removeClass('btn-primary');
+      this.$('.server-output-btn').addClass('btn-default');
+      this.$('.server-graph-btn').removeClass('btn-default');
+      this.$('.server-graph-btn').addClass('btn-primary');
+      this.$('.server-output-clear').hide();
+      this.$('.server-graph-period').show();
+      this.serverOutputView.setState(false);
+      this.serverBandwidthView.setState(true);
+    },
     _updateTime: function() {
       if (!this.model.get('uptime')) {
         return;
